# Napistu Python Library

This Python package hosts the majority of the algorithmic code for the [Napistu project](https://github.com/napistu/napistu).

## Setup

Currently the only way to use this repository is to clone the repo and perform a local install. e.g., from this directory:

```bash
pip install .
```
